@@ -21,6 +21,7 @@ class Edge(BaseDriver):
 
     Args:
         edge_options (Options): Edge automation session desired capabilities and options
+        desired_capabilities (dict): Dictionary object containing desired capabilities for Chrome automation session
         token (str): The developer token used to communicate with the agent
         projectname (str): Project name to report
         jobname (str): Job name to report
@@ -29,14 +30,26 @@ class Edge(BaseDriver):
 
     def __init__(
         self,
-        edge_options: Options = Options(),
+        edge_options: Options = None,
+        desired_capabilities: dict = None,
         token: str = None,
         projectname: str = None,
         jobname: str = None,
         disable_reports: bool = False,
     ):
+        # If no options or capabilities are specified at all, use default Options
+        if edge_options is None and desired_capabilities is None:
+            caps = Options().to_capabilities()
+        else:
+            # Specified EdgeOptions take precedence over desired capabilities but either can be used
+            caps = (
+                edge_options.to_capabilities()
+                if edge_options is not None
+                else desired_capabilities
+            )
+
         super().__init__(
-            capabilities=edge_options.to_capabilities(),
+            capabilities=caps,
             token=token,
             projectname=projectname,
             jobname=jobname,
